# EUR-Lex Parser

An EUR-Lex parser for Python.

## Usage

You can install the package with [`pip`](https://pip.pypa.io/en/stable/getting-started/):

```bash
pip install eurlex
```

## Code Contribution

Feel free to send any issues, ideas or pull requests. If you want to commit code, make sure to use `black` to format your code.